pub struct Wallet { /* private fields */ }Implementations
Sourceimpl Wallet
impl Wallet
Sourcepub async fn load(
wallet_name: Option<String>,
create_on_undefined: bool,
) -> Result<Self, WalletError>
pub async fn load( wallet_name: Option<String>, create_on_undefined: bool, ) -> Result<Self, WalletError>
Load a wallet by name, optionally creating one if it doesn’t exist
Sourcepub fn get_mnemonic(&self) -> Result<&str, WalletError>
pub fn get_mnemonic(&self) -> Result<&str, WalletError>
Get the mnemonic seed phrase
Sourcepub fn get_wallet_name(&self) -> &str
pub fn get_wallet_name(&self) -> &str
Get the wallet name
Sourcepub async fn create_new_wallet(wallet_name: &str) -> Result<String, WalletError>
pub async fn create_new_wallet(wallet_name: &str) -> Result<String, WalletError>
Create a new wallet with a generated mnemonic
Sourcepub async fn import_wallet(
wallet_name: &str,
seed: Option<&str>,
) -> Result<String, WalletError>
pub async fn import_wallet( wallet_name: &str, seed: Option<&str>, ) -> Result<String, WalletError>
Import a wallet from a provided mnemonic
Sourcepub async fn get_master_secret_key(&self) -> Result<SecretKey, WalletError>
pub async fn get_master_secret_key(&self) -> Result<SecretKey, WalletError>
Get the master secret key from the mnemonic
Sourcepub async fn get_public_synthetic_key(&self) -> Result<PublicKey, WalletError>
pub async fn get_public_synthetic_key(&self) -> Result<PublicKey, WalletError>
Get the public synthetic key
Sourcepub async fn get_private_synthetic_key(&self) -> Result<SecretKey, WalletError>
pub async fn get_private_synthetic_key(&self) -> Result<SecretKey, WalletError>
Get the private synthetic key
Sourcepub async fn get_owner_puzzle_hash(&self) -> Result<Bytes32, WalletError>
pub async fn get_owner_puzzle_hash(&self) -> Result<Bytes32, WalletError>
Get the owner puzzle hash
Sourcepub async fn get_owner_public_key(&self) -> Result<String, WalletError>
pub async fn get_owner_public_key(&self) -> Result<String, WalletError>
Get the owner public key as an address
Sourcepub async fn delete_wallet(wallet_name: &str) -> Result<bool, WalletError>
pub async fn delete_wallet(wallet_name: &str) -> Result<bool, WalletError>
Delete a wallet from the keyring
Sourcepub async fn list_wallets() -> Result<Vec<String>, WalletError>
pub async fn list_wallets() -> Result<Vec<String>, WalletError>
List all wallets in the keyring
Sourcepub async fn create_key_ownership_signature(
&self,
nonce: &str,
) -> Result<String, WalletError>
pub async fn create_key_ownership_signature( &self, nonce: &str, ) -> Result<String, WalletError>
Create a key ownership signature
Sourcepub async fn verify_key_ownership_signature(
nonce: &str,
signature: &str,
public_key: &str,
) -> Result<bool, WalletError>
pub async fn verify_key_ownership_signature( nonce: &str, signature: &str, public_key: &str, ) -> Result<bool, WalletError>
Verify a key ownership signature
Sourcepub async fn select_unspent_coins(
&self,
peer: &Peer,
coin_amount: u64,
fee: u64,
omit_coins: Vec<Coin>,
) -> Result<Vec<Coin>, WalletError>
pub async fn select_unspent_coins( &self, peer: &Peer, coin_amount: u64, fee: u64, omit_coins: Vec<Coin>, ) -> Result<Vec<Coin>, WalletError>
Select unspent coins for spending
Sourcepub async fn calculate_fee_for_coin_spends(
_peer: &Peer,
_coin_spends: Option<&[CoinSpend]>,
) -> Result<u64, WalletError>
pub async fn calculate_fee_for_coin_spends( _peer: &Peer, _coin_spends: Option<&[CoinSpend]>, ) -> Result<u64, WalletError>
Calculate fee for coin spends
Sourcepub async fn is_coin_spendable(
peer: &Peer,
coin_id: &Bytes32,
) -> Result<bool, WalletError>
pub async fn is_coin_spendable( peer: &Peer, coin_id: &Bytes32, ) -> Result<bool, WalletError>
Check if a coin is spendable
Sourcepub async fn connect_random_peer(
network: NetworkType,
cert_path: &str,
key_path: &str,
) -> Result<Peer, WalletError>
pub async fn connect_random_peer( network: NetworkType, cert_path: &str, key_path: &str, ) -> Result<Peer, WalletError>
Connect to a random peer on the specified network
Sourcepub async fn connect_mainnet_peer() -> Result<Peer, WalletError>
pub async fn connect_mainnet_peer() -> Result<Peer, WalletError>
Connect to a random mainnet peer using default Chia SSL paths
Sourcepub async fn connect_testnet_peer() -> Result<Peer, WalletError>
pub async fn connect_testnet_peer() -> Result<Peer, WalletError>
Connect to a random testnet peer using default Chia SSL paths
Sourcepub fn address_to_puzzle_hash(address: &str) -> Result<Bytes32, WalletError>
pub fn address_to_puzzle_hash(address: &str) -> Result<Bytes32, WalletError>
Convert an address to a puzzle hash
Sourcepub fn puzzle_hash_to_address(
puzzle_hash: Bytes32,
prefix: &str,
) -> Result<String, WalletError>
pub fn puzzle_hash_to_address( puzzle_hash: Bytes32, prefix: &str, ) -> Result<String, WalletError>
Convert a puzzle hash to an address